==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/iot_provisioning_template/IotProvisioningTemplatePreProvisioningHook.java <==
package com.hashicorp.cdktf.providers.aws.iot_provisioning_template;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.311Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.iotProvisioningTemplate.IotProvisioningTemplatePreProvisioningHook")
@software.amazon.jsii.Jsii.Proxy(IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IotProvisioningTemplatePreProvisioningHook extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_provisioning_template#target_arn IotProvisioningTemplate#target_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetArn();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_provisioning_template#payload_version IotProvisioningTemplate#payload_version}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPayloadVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<IotProvisioningTemplatePreProvisioningHook> {
        java.lang.String targetArn;
        java.lang.String payloadVersion;

        /**
         * Sets the value of {@link IotProvisioningTemplatePreProvisioningHook#getTargetArn}
         * @param targetArn Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_provisioning_template#target_arn IotProvisioningTemplate#target_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetArn(java.lang.String targetArn) {
            this.targetArn = targetArn;
            return this;
        }

        /**
         * Sets the value of {@link IotProvisioningTemplatePreProvisioningHook#getPayloadVersion}
         * @param payloadVersion Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_provisioning_template#payload_version IotProvisioningTemplate#payload_version}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder payloadVersion(java.lang.String payloadVersion) {
            this.payloadVersion = payloadVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IotProvisioningTemplatePreProvisioningHook}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public IotProvisioningTemplatePreProvisioningHook build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IotProvisioningTemplatePreProvisioningHook {
        private final java.lang.String targetArn;
        private final java.lang.String payloadVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetArn = software.amazon.jsii.Kernel.get(this, "targetArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.payloadVersion = software.amazon.jsii.Kernel.get(this, "payloadVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetArn = java.util.Objects.requireNonNull(builder.targetArn, "targetArn is required");
            this.payloadVersion = builder.payloadVersion;
        }

        @Override
        public final java.lang.String getTargetArn() {
            return this.targetArn;
        }

        @Override
        public final java.lang.String getPayloadVersion() {
            return this.payloadVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetArn", om.valueToTree(this.getTargetArn()));
            if (this.getPayloadVersion() != null) {
                data.set("payloadVersion", om.valueToTree(this.getPayloadVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.iotProvisioningTemplate.IotProvisioningTemplatePreProvisioningHook"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy that = (IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy) o;

            if (!targetArn.equals(that.targetArn)) return false;
            return this.payloadVersion != null ? this.payloadVersion.equals(that.payloadVersion) : that.payloadVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.targetArn.hashCode();
            result = 31 * result + (this.payloadVersion != null ? this.payloadVersion.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/iot_provisioning_template/IotProvisioningTemplatePreProvisioningHook.java <==
package com.hashicorp.cdktf.providers.aws.iot_provisioning_template;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.138Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.iotProvisioningTemplate.IotProvisioningTemplatePreProvisioningHook")
@software.amazon.jsii.Jsii.Proxy(IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IotProvisioningTemplatePreProvisioningHook extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/iot_provisioning_template#target_arn IotProvisioningTemplate#target_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetArn();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/iot_provisioning_template#payload_version IotProvisioningTemplate#payload_version}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPayloadVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<IotProvisioningTemplatePreProvisioningHook> {
        java.lang.String targetArn;
        java.lang.String payloadVersion;

        /**
         * Sets the value of {@link IotProvisioningTemplatePreProvisioningHook#getTargetArn}
         * @param targetArn Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/iot_provisioning_template#target_arn IotProvisioningTemplate#target_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetArn(java.lang.String targetArn) {
            this.targetArn = targetArn;
            return this;
        }

        /**
         * Sets the value of {@link IotProvisioningTemplatePreProvisioningHook#getPayloadVersion}
         * @param payloadVersion Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/iot_provisioning_template#payload_version IotProvisioningTemplate#payload_version}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder payloadVersion(java.lang.String payloadVersion) {
            this.payloadVersion = payloadVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link IotProvisioningTemplatePreProvisioningHook}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public IotProvisioningTemplatePreProvisioningHook build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link IotProvisioningTemplatePreProvisioningHook}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements IotProvisioningTemplatePreProvisioningHook {
        private final java.lang.String targetArn;
        private final java.lang.String payloadVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetArn = software.amazon.jsii.Kernel.get(this, "targetArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.payloadVersion = software.amazon.jsii.Kernel.get(this, "payloadVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetArn = java.util.Objects.requireNonNull(builder.targetArn, "targetArn is required");
            this.payloadVersion = builder.payloadVersion;
        }

        @Override
        public final java.lang.String getTargetArn() {
            return this.targetArn;
        }

        @Override
        public final java.lang.String getPayloadVersion() {
            return this.payloadVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetArn", om.valueToTree(this.getTargetArn()));
            if (this.getPayloadVersion() != null) {
                data.set("payloadVersion", om.valueToTree(this.getPayloadVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.iotProvisioningTemplate.IotProvisioningTemplatePreProvisioningHook"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy that = (IotProvisioningTemplatePreProvisioningHook.Jsii$Proxy) o;

            if (!targetArn.equals(that.targetArn)) return false;
            return this.payloadVersion != null ? this.payloadVersion.equals(that.payloadVersion) : that.payloadVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.targetArn.hashCode();
            result = 31 * result + (this.payloadVersion != null ? this.payloadVersion.hashCode() : 0);
            return result;
        }
    }
}
